.. image:: https://raw.githubusercontent.com/x-m-01/mail/master/IMG_20200713_201421.jpg


::

    $ pip3 install mdi

    $ mdi -h

**MDI**

- Downloads **public photos and videos**,


::

    mdi [-h] [-q] [-d] [-p PATH] url



Disclaimer
----------

.. disclaimer-start

MDI is a simple pip for downloading instagram videos and photos

MDI is licensed under an MIT license. Refer to ``LICENSE`` file for more information.

.. disclaimer-end
